import { ValidationHtmlConfiguration, ValidationTrigger } from '@aurelia/validation-html';
import { bindable, customAttribute, INode, CustomElement, customElement, watch, valueConverter } from '@aurelia/runtime-html';
import { IPlatform, DI, Registration } from '@aurelia/kernel';
import { MDCTopAppBar } from '@material/top-app-bar';
import { MDCDrawer } from '@material/drawer';
import 'devextreme/dist/css/dx.material.purple.dark.compact.css';
import { MDCDialog } from '@material/dialog';
import { MDCTextField } from '@material/textfield';
import { observable } from '@aurelia/runtime';
import { MDCCircularProgress } from '@material/circular-progress';
import { MDCRipple } from '@material/ripple';
import '@material/web/switch/switch';
import DataGrid from 'devextreme/ui/data_grid';
import { MDCTabBar } from '@material/tab-bar';
import { MDCSelect } from '@material/select';
import { MDCBanner, CloseReason } from '@material/banner';
import { MDCRadio } from '@material/radio';
import { MDCFormField } from '@material/form-field';
import { MDCChipSet } from '@material/chips';
import { MDCCheckbox } from '@material/checkbox';
import { MDCMenu } from '@material/menu';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */


function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __param(paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
}

function __metadata(metadataKey, metadataValue) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}

let Align = class Align {
    element;
    value;
    constructor(element){
        this.element = element;
    }
    afterBind() {
        this.element.style.textAlign = this.value ?? '';
    }
    /* Example of change detection */ valueChanged() {
        this.afterBind();
    }
};
__decorate([
    bindable(),
    __metadata("design:type", String)
], Align.prototype, "value", void 0);
Align = __decorate([
    customAttribute({
        name: 'align'
    }),
    __param(0, INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], Align);

let FullHeight = class FullHeight {
    element;
    constructor(element){
        this.element = element;
        this.element.style.height = '100%';
    }
};
FullHeight = __decorate([
    customAttribute({
        name: 'full-height'
    }),
    __param(0, INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], FullHeight);

let FullWidth = class FullWidth {
    element;
    constructor(element){
        this.element = element;
        this.element.style.width = '100%';
    }
};
FullWidth = __decorate([
    customAttribute({
        name: 'full-width'
    }),
    __param(0, INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], FullWidth);

let Link = class Link {
    htmlElement;
    platform;
    value = '';
    constructor(htmlElement, platform){
        this.htmlElement = htmlElement;
        this.platform = platform;
        htmlElement.addEventListener('mousedown', this.clickEvent);
    }
    clickEvent = ()=>{
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        //@ts-ignore
        this.platform.window.open(this.value, '_blank');
    };
    detaching() {
        this.htmlElement.removeEventListener('mousedown', this.clickEvent);
    }
};
__decorate([
    bindable,
    __metadata("design:type", Object)
], Link.prototype, "value", void 0);
Link = __decorate([
    customAttribute({
        name: 'link',
        noMultiBindings: true
    }),
    __param(0, INode),
    __param(1, IPlatform),
    __metadata("design:paramtypes", [
        HTMLElement,
        Object
    ])
], Link);

let Ripple = class Ripple {
    htmlElement;
    platform;
    speed = 1;
    color = '';
    rippleContainer;
    ripple;
    constructor(htmlElement, platform){
        this.htmlElement = htmlElement;
        this.platform = platform;
        htmlElement?.addEventListener('mousedown', this.rippleEvent);
    }
    rippleEvent = (event)=>{
        if (!this.htmlElement) return;
        const offsetInfo = this.htmlElement.getBoundingClientRect();
        this.createContainer(offsetInfo);
        this.createRipple(offsetInfo, event);
    };
    createRipple = (offsetInfo, event)=>{
        const maxLength = offsetInfo.width > offsetInfo.height ? offsetInfo.width : offsetInfo.height;
        const circleD = maxLength * 2;
        this.ripple = document.createElement('div');
        this.ripple.style.position = 'absolute';
        this.ripple.style.pointerEvents = 'none';
        this.ripple.style.width = `${circleD}px`;
        this.ripple.style.height = `${circleD}px`;
        this.ripple.style.borderRadius = '500px';
        this.ripple.style.left = `${event.pageX - offsetInfo.left - circleD / 2}px`;
        this.ripple.style.top = `${event.pageY - offsetInfo.top - circleD / 2}px`;
        this.ripple.style.animationDuration = `${this.speed}s`;
        this.ripple.style.background = this.color || 'rgba(var(--san-juan-900-rgb), var(--alpha-sm))';
        this.ripple.className = 'ripple';
        this.rippleContainer?.appendChild(this.ripple);
        this.ripple.addEventListener('animationend', this.removeContainer, false);
    };
    createContainer(offsetInfo) {
        if (!this.htmlElement) return;
        const ripplerContainer = this.htmlElement.querySelector('.ripple-container');
        if (ripplerContainer) {
            ripplerContainer.remove();
        }
        this.rippleContainer = document.createElement('div');
        this.rippleContainer.style.position = 'fixed';
        this.rippleContainer.style.zIndex = '99';
        this.rippleContainer.style.width = `${offsetInfo.width}px`;
        this.rippleContainer.style.left = `${offsetInfo.left}px`;
        this.rippleContainer.style.top = `${offsetInfo.top}px`;
        this.rippleContainer.style.height = `${offsetInfo.height}px`;
        this.rippleContainer.className = 'ripple-container';
        this.rippleContainer.style.pointerEvents = 'none';
        this.rippleContainer.style.overflow = 'hidden';
        this.htmlElement.appendChild(this.rippleContainer);
    }
    removeContainer = ()=>{
        this.rippleContainer?.remove();
        this.ripple?.removeEventListener('animationend', this.removeContainer);
    };
    detaching() {
        if (!this.htmlElement) return;
        this.htmlElement.removeEventListener('mousedown', this.rippleEvent);
    }
};
__decorate([
    bindable,
    __metadata("design:type", Object)
], Ripple.prototype, "speed", void 0);
__decorate([
    bindable({
        primary: true
    }),
    __metadata("design:type", Object)
], Ripple.prototype, "color", void 0);
Ripple = __decorate([
    customAttribute({
        name: 'ripple'
    }),
    __param(1, IPlatform),
    __metadata("design:paramtypes", [
        HTMLElement,
        Object
    ])
], Ripple);

let Underline = class Underline {
    element;
    constructor(element){
        this.element = element;
        this.element.style.textDecoration = 'underline';
    }
};
Underline = __decorate([
    customAttribute({
        name: 'underline'
    }),
    __param(0, INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], Underline);

let Elevation = class Elevation {
    element;
    value;
    constructor(element){
        this.element = element;
        this.element.style.boxShadow = '0 8px 12px rgba(0, 0, 0, 0.1), 0 2px 6px rgba(0, 0, 0, 0.08)';
        //this.element.style.border = "1px solid black";
        this.element.style.borderRadius = '5px';
    }
};
__decorate([
    bindable(),
    __metadata("design:type", String)
], Elevation.prototype, "value", void 0);
Elevation = __decorate([
    customAttribute({
        name: 'elevation'
    }),
    __param(0, INode),
    __metadata("design:paramtypes", [
        HTMLElement
    ])
], Elevation);

const attributes = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get Align () { return Align; },
    get Elevation () { return Elevation; },
    get FullHeight () { return FullHeight; },
    get FullWidth () { return FullWidth; },
    get Link () { return Link; },
    get Ripple () { return Ripple; },
    get Underline () { return Underline; }
}, Symbol.toStringTag, { value: 'Module' }));

const IBetsyWebComponentsConfiguration = DI.createInterface('IBetsyWebComponentsConfiguration');

const mooButton = '';

const name$p = "moo-button";
const template$p = "<button class=\"moo-button ${colorClass} ${class}\" ref=\"button\" type=\"${type}\" if.bind=\"!hasClickFunction\" data-mdc-dialog-action.bind=\"dataMdcDialogAction\" disabled.bind=\"disabled\">\n    <span class=\"material-icons\" if.bind=\"icon\">${icon}</span>\n    ${label}<au-slot></au-slot>\n</button>\n\n<button else class=\"moo-button ${colorClass} ${class}\" ref=\"button\" type=\"${type}\" click.trigger=\"handleClick()\" data-mdc-dialog-action.bind=\"dataMdcDialogAction\" disabled.bind=\"disabled\">\n    <span class=\"material-icons\" if.bind=\"icon\">${icon}</span>\n    ${label}<au-slot></au-slot>\n</button>\n";
const dependencies$p = [];
let _e$p;
function register$p(container) {
    if (!_e$p) {
        _e$p = CustomElement.define({
            name: name$p,
            template: template$p,
            dependencies: dependencies$p
        });
    }
    container.register(_e$p);
}

const __au2ViewDef$p = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$p,
    dependencies: dependencies$p,
    name: name$p,
    register: register$p,
    template: template$p
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$p(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooButton = class MooButton {
    static containerless = true;
    button;
    label;
    type;
    icon;
    variant = 'primary';
    class = '';
    click;
    dataMdcDialogAction;
    disabled = false;
    get colorClass() {
        switch(this.variant){
            case 'primary':
                return '';
            case 'secondary':
                return 'moo-button-secondary';
        }
    }
    handleClick() {
        if (this.click) {
            this.click();
        }
    }
    get hasClickFunction() {
        return typeof this.click === 'function';
    }
};
MooButton = _ts_decorate$p([
    customElement(__au2ViewDef$p)
], MooButton);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooButton.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooButton.prototype, "type", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooButton.prototype, "icon", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooButton.prototype, "variant", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooButton.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Function)
], MooButton.prototype, "click", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooButton.prototype, "dataMdcDialogAction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooButton.prototype, "disabled", void 0);

const mooTopbar = '';

const name$o = "moo-topbar";
const template$o = "<header class=\"mdc-top-app-bar mdc-top-app-bar--fixed\" ref=\"header\">\n    <div class=\"mdc-top-app-bar__row\">\n        <au-slot></au-slot>\n    </div>\n</header>\n<div class=\"mdc-top-app-bar--fixed-adjust\"></div>\n";
const dependencies$o = [];
let _e$o;
function register$o(container) {
    if (!_e$o) {
        _e$o = CustomElement.define({
            name: name$o,
            template: template$o,
            dependencies: dependencies$o
        });
    }
    container.register(_e$o);
}

const __au2ViewDef$o = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$o,
    dependencies: dependencies$o,
    name: name$o,
    register: register$o,
    template: template$o
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$o(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooTopbar = class MooTopbar {
    static containerless = true;
    header;
    attached() {
        new MDCTopAppBar(this.header);
    }
} 
;
MooTopbar = _ts_decorate$o([
    customElement(__au2ViewDef$o)
], MooTopbar);

const mooDrawer = '';

const name$n = "moo-drawer";
const template$n = "<div if.bind=\"!open\">\n    <moo-fab icon=\"chevron_right\" click.bind=\"() => open = true\" class=\"bottomRight\"></moo-fab>\n</div>\n<aside class=\"mdc-drawer mdc-drawer--dismissible\" ref=\"drawerEl\">\n    <div class=\"close-icon\">\n        <moo-fab icon=\"chevron_left\" click.bind=\"() => open = false\" class=\"topRight\"></moo-fab>\n    </div>\n    <div class=\"mdc-drawer__content\">\n        <au-slot></au-slot>\n    </div>\n</aside>\n";
const dependencies$n = [];
let _e$n;
function register$n(container) {
    if (!_e$n) {
        _e$n = CustomElement.define({
            name: name$n,
            template: template$n,
            dependencies: dependencies$n
        });
    }
    container.register(_e$n);
}

const __au2ViewDef$n = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$n,
    dependencies: dependencies$n,
    name: name$n,
    register: register$n,
    template: template$n
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$n(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooDrawer = class MooDrawer {
    static containerless = true;
    open;
    drawerEl;
    drawer;
    didAttach = false;
    attached() {
        if (!this.didAttach) {
            this.drawer = MDCDrawer.attachTo(this.drawerEl);
            this.drawer.open = this.open;
            this.didAttach = true;
        }
    }
    openChanged() {
        this.drawer.open = this.open;
    }
};
MooDrawer = _ts_decorate$n([
    customElement(__au2ViewDef$n)
], MooDrawer);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooDrawer.prototype, "open", void 0);

const mooDialog = '';

const name$m = "moo-dialog";
const template$m = "<div class=\"mdc-dialog\" ref=\"dialogEl\">\n    <div class=\"mdc-dialog__container\">\n        <div class=\"mdc-dialog__surface\"\n             role=\"alertdialog\"\n             aria-modal=\"true\"\n             aria-labelledby=\"my-dialog-title\"\n             aria-describedby=\"my-dialog-content\">\n            <h2 class=\"mdc-dialog__title\" id=\"my-dialog-title\" if.bind=\"title\">${title}</h2>\n            <div class=\"mdc-dialog__content\" id=\"my-dialog-content\">\n                <au-slot></au-slot>\n            </div>\n            <div class=\"mdc-dialog__actions\">\n                <moo-button type=\"button\" variant=\"secondary\" data-mdc-dialog-action=\"cancel\">\n                    Cancel\n                </moo-button>\n                <moo-button type=\"button\" variant=\"primary\" data-mdc-dialog-action=\"ok\" class=\"ms-3\">\n                    Confirm\n                </moo-button>\n            </div>\n        </div>\n    </div>\n    <div class=\"mdc-dialog__scrim\"></div>\n</div>\n";
const dependencies$m = [];
let _e$m;
function register$m(container) {
    if (!_e$m) {
        _e$m = CustomElement.define({
            name: name$m,
            template: template$m,
            dependencies: dependencies$m
        });
    }
    container.register(_e$m);
}

const __au2ViewDef$m = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$m,
    dependencies: dependencies$m,
    name: name$m,
    register: register$m,
    template: template$m
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$m(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooDialog = class MooDialog {
    static containerless = true;
    dialogEl;
    dialog;
    handler;
    title;
    attached() {
        this.dialog = new MDCDialog(this.dialogEl);
        this.dialog.listen('MDCDialog:closed', (e)=>{
            if (this.handler) {
                this.handler(e);
            }
        });
    }
};
MooDialog = _ts_decorate$m([
    customElement(__au2ViewDef$m)
], MooDialog);
__decorate([
    bindable,
    __metadata("design:type", HTMLElement)
], MooDialog.prototype, "dialogEl", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", MDCDialog)
], MooDialog.prototype, "dialog", void 0);
__decorate([
    bindable,
    __metadata("design:type", Function)
], MooDialog.prototype, "handler", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooDialog.prototype, "title", void 0);

const mooCard = '';

const name$l = "moo-card";
const template$l = "<div class=\"card\">\n    <au-slot></au-slot>\n</div>\n";
const dependencies$l = [];
let _e$l;
function register$l(container) {
    if (!_e$l) {
        _e$l = CustomElement.define({
            name: name$l,
            template: template$l,
            dependencies: dependencies$l
        });
    }
    container.register(_e$l);
}

const __au2ViewDef$l = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$l,
    dependencies: dependencies$l,
    name: name$l,
    register: register$l,
    template: template$l
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$l(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooCard = class MooCard {
    static containerless = true;
    outlined;
};
MooCard = _ts_decorate$l([
    customElement(__au2ViewDef$l)
], MooCard);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooCard.prototype, "outlined", void 0);

const name$k = "moo-card-header";
const template$k = "<div class=\"card-header\">\n    <au-slot></au-slot>\n</div>\n";
const dependencies$k = [];
let _e$k;
function register$k(container) {
    if (!_e$k) {
        _e$k = CustomElement.define({
            name: name$k,
            template: template$k,
            dependencies: dependencies$k
        });
    }
    container.register(_e$k);
}

const __au2ViewDef$k = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$k,
    dependencies: dependencies$k,
    name: name$k,
    register: register$k,
    template: template$k
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$k(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooCardHeader = class MooCardHeader {
    static containerless = true;
    outlined;
};
MooCardHeader = _ts_decorate$k([
    customElement(__au2ViewDef$k)
], MooCardHeader);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooCardHeader.prototype, "outlined", void 0);

const name$j = "moo-card-content";
const template$j = "<div class=\"card-content\">\n    <au-slot></au-slot>\n</div>\n";
const dependencies$j = [];
let _e$j;
function register$j(container) {
    if (!_e$j) {
        _e$j = CustomElement.define({
            name: name$j,
            template: template$j,
            dependencies: dependencies$j
        });
    }
    container.register(_e$j);
}

const __au2ViewDef$j = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$j,
    dependencies: dependencies$j,
    name: name$j,
    register: register$j,
    template: template$j
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$j(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooCardContent = class MooCardContent {
    static containerless = true;
    outlined;
};
MooCardContent = _ts_decorate$j([
    customElement(__au2ViewDef$j)
], MooCardContent);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooCardContent.prototype, "outlined", void 0);

const name$i = "moo-card-footer";
const template$i = "<div class=\"card-footer\">\n    <au-slot></au-slot>\n</div>\n";
const dependencies$i = [];
let _e$i;
function register$i(container) {
    if (!_e$i) {
        _e$i = CustomElement.define({
            name: name$i,
            template: template$i,
            dependencies: dependencies$i
        });
    }
    container.register(_e$i);
}

const __au2ViewDef$i = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$i,
    dependencies: dependencies$i,
    name: name$i,
    register: register$i,
    template: template$i
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$i(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooCardFooter = class MooCardFooter {
    static containerless = true;
    outlined;
};
MooCardFooter = _ts_decorate$i([
    customElement(__au2ViewDef$i)
], MooCardFooter);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooCardFooter.prototype, "outlined", void 0);

const name$h = "moo-list-item";
const template$h = "<a load=\"${route}\" if.bind=\"route\">\n    <li class=\"mdc-deprecated-list-item ${disabledClass}\" data-value=\"${value}\">\n        <span class=\"mdc-deprecated-list-item__ripple\"></span>\n        <span class=\"mdc-deprecated-list-item__text\">${label}</span>\n    </li>\n</a>\n<li class=\"mdc-deprecated-list-item ${disabledClass}\" data-value=\"${value}\" click.trigger=\"clickHandler()\" else>\n    <span class=\"mdc-deprecated-list-item__ripple\"></span>\n    <span class=\"mdc-deprecated-list-item__text\">${label}</span>\n</li>\n";
const dependencies$h = [];
let _e$h;
function register$h(container) {
    if (!_e$h) {
        _e$h = CustomElement.define({
            name: name$h,
            template: template$h,
            dependencies: dependencies$h
        });
    }
    container.register(_e$h);
}

const __au2ViewDef$h = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$h,
    dependencies: dependencies$h,
    name: name$h,
    register: register$h,
    template: template$h
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$h(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooListItem = class MooListItem {
    static containerless = true;
    label;
    value;
    route;
    click;
    disabled = false;
    clickHandler() {
        if (this.click) {
            this.click(this.value);
        }
    }
    get disabledClass() {
        if (this.disabled) {
            return 'mdc-deprecated-list-item--disabled';
        }
    }
};
MooListItem = _ts_decorate$h([
    customElement(__au2ViewDef$h)
], MooListItem);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooListItem.prototype, "label", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooListItem.prototype, "value", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooListItem.prototype, "route", void 0);
__decorate([
    bindable,
    __metadata("design:type", Function)
], MooListItem.prototype, "click", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooListItem.prototype, "disabled", void 0);

const mooTextField = '';

const name$g = "moo-text-field";
const template$g = "<div switch.bind=\"type\">\n    <label class=\"mdc-text-field mdc-text-field--filled ${class} ${floatLabelClass}\" case.bind=\"['text', 'number']\" ref=\"input\">\n        <span class=\"mdc-text-field__ripple\"></span>\n        <span class=\"mdc-floating-label\" id=\"my-label-id\">${label}</span>\n        <input class=\"mdc-text-field__input\"\n               type.bind=\"type\"\n               aria-labelledby=\"my-label-id\"\n               value.bind=\"value\"\n               required.bind=\"required\"\n               readonly.bind=\"readonly\"\n               minlength.bind=\"minlength\"\n               maxlength.bind=\"maxlength\"\n               min.bind=\"min\"\n               max.bind=\"max\"\n               placeholder.bind=\"placeholder\"\n        >\n    </label>\n    <label class=\"mdc-text-field mdc-text-field--outlined mdc-text-field--textarea mdc-text-field--no-label ${class}\"\n           case=\"textarea\" ref=\"input\">\n            <span class=\"mdc-notched-outline\">\n              <span class=\"mdc-notched-outline__leading\"></span>\n              <span class=\"mdc-notched-outline__trailing\"></span>\n            </span>\n        <span class=\"mdc-text-field__resizer\">\n              <textarea\n                  class=\"mdc-text-field__input\"\n                  rows.bind=\"rows\"\n                  cols.bind=\"cols\"\n                  aria-label=\"${label}\"\n                  value.bind=\"value\"\n                  readonly.bind=\"readonly\"\n                  minlength.bind=\"min\"\n                  maxlength=\"max\"\n                  placeholder.bind=\"placeholder\"\n              ></textarea>\n            </span>\n    </label>\n    <div class=\"mdc-text-field-helper-line\" if.bind=\"maxlength\">\n        <div class=\"mdc-text-field-character-counter\">${value.length} / ${maxlength}</div>\n    </div>\n</div>\n";
const dependencies$g = [];
let _e$g;
function register$g(container) {
    if (!_e$g) {
        _e$g = CustomElement.define({
            name: name$g,
            template: template$g,
            dependencies: dependencies$g
        });
    }
    container.register(_e$g);
}

const __au2ViewDef$g = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$g,
    dependencies: dependencies$g,
    name: name$g,
    register: register$g,
    template: template$g
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$g(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooTextField = class MooTextField {
    static containerless = true;
    value;
    label;
    class;
    type = 'text';
    rows;
    cols;
    input;
    readonly;
    min;
    max;
    minlength;
    maxlength;
    required;
    placeholder;
    textField;
    attached() {
        if (this.input) {
            this.textField = new MDCTextField(this.input);
        }
    }
    get floatLabelClass() {
        if (this.value == undefined) {
            return '';
        }
        return 'mdc-text-field--label-floating';
    }
};
MooTextField = _ts_decorate$g([
    customElement(__au2ViewDef$g)
], MooTextField);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooTextField.prototype, "value", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "type", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "rows", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "cols", void 0);
__decorate([
    observable,
    __metadata("design:type", HTMLElement)
], MooTextField.prototype, "input", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "readonly", void 0);
__decorate([
    bindable,
    __metadata("design:type", Number)
], MooTextField.prototype, "min", void 0);
__decorate([
    bindable,
    __metadata("design:type", Number)
], MooTextField.prototype, "max", void 0);
__decorate([
    bindable,
    __metadata("design:type", Number)
], MooTextField.prototype, "minlength", void 0);
__decorate([
    bindable,
    __metadata("design:type", Number)
], MooTextField.prototype, "maxlength", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "required", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTextField.prototype, "placeholder", void 0);

const mooCircularProgress = '';

const name$f = "moo-circular-progress";
const template$f = "<div class=\"mdc-circular-progress\" style=\"width:48px;height:48px;\" role=\"progressbar\" aria-label=\"Example Progress Bar\" aria-valuemin=\"0\" aria-valuemax=\"1\" ref=\"progressEl\">\n    <div class=\"mdc-circular-progress__determinate-container\">\n        <svg class=\"mdc-circular-progress__determinate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n            <circle class=\"mdc-circular-progress__determinate-track\" cx=\"24\" cy=\"24\" r=\"18\" stroke-width=\"4\"/>\n            <circle class=\"mdc-circular-progress__determinate-circle\" cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"113.097\" stroke-width=\"4\"/>\n        </svg>\n    </div>\n    <div class=\"mdc-circular-progress__indeterminate-container\">\n        <div class=\"mdc-circular-progress__spinner-layer\">\n            <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-left\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"4\"/>\n                </svg>\n            </div>\n            <div class=\"mdc-circular-progress__gap-patch\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"3.2\"/>\n                </svg>\n            </div>\n            <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-right\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"4\"/>\n                </svg>\n            </div>\n        </div>\n    </div>\n</div>\n";
const dependencies$f = [];
let _e$f;
function register$f(container) {
    if (!_e$f) {
        _e$f = CustomElement.define({
            name: name$f,
            template: template$f,
            dependencies: dependencies$f
        });
    }
    container.register(_e$f);
}

const __au2ViewDef$f = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$f,
    dependencies: dependencies$f,
    name: name$f,
    register: register$f,
    template: template$f
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$f(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooCircularProgress = class MooCircularProgress {
    static containerless = true;
    progressEl;
    size;
    attached() {
        const progress = new MDCCircularProgress(this.progressEl);
        progress.determinate = false;
        progress.open();
    }
};
MooCircularProgress = _ts_decorate$f([
    customElement(__au2ViewDef$f)
], MooCircularProgress);
__decorate([
    bindable,
    __metadata("design:type", Number)
], MooCircularProgress.prototype, "size", void 0);

const mooFab = '';

const name$e = "moo-fab";
const template$e = "<button if.bind=\"!url && !route\" class=\"mdc-fab ${extendedClass} ${class}\" aria-label=\"${icon}\" ref=\"fabEl\" click.trigger=\"handleClick()\">\n    <div class=\"mdc-fab__ripple\"></div>\n    <span class=\"mdc-fab__icon material-icons\">${icon}</span>\n    <span class=\"mdc-fab__label\">${label}</span>\n</button>\n<a if.bind=\"url\" href=\"${url}\" class=\"mdc-fab ${extendedClass} ${class}\" aria-label=\"${icon}\" ref=\"fabEl\" external target=\"_blank\">\n    <div class=\"mdc-fab__ripple\"></div>\n    <span class=\"mdc-fab__icon material-icons\">${icon}</span>\n    <span class=\"mdc-fab__label\">${label}</span>\n</a>\n<a if.bind=\"route\" load=\"${route}\" class=\"mdc-fab ${extendedClass} ${class}\" aria-label=\"${icon}\" ref=\"fabEl\">\n    <div class=\"mdc-fab__ripple\"></div>\n    <span class=\"mdc-fab__icon material-icons\">${icon}</span>\n    <span class=\"mdc-fab__label\">${label}</span>\n</a>\n";
const dependencies$e = [];
let _e$e;
function register$e(container) {
    if (!_e$e) {
        _e$e = CustomElement.define({
            name: name$e,
            template: template$e,
            dependencies: dependencies$e
        });
    }
    container.register(_e$e);
}

const __au2ViewDef$e = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$e,
    dependencies: dependencies$e,
    name: name$e,
    register: register$e,
    template: template$e
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$e(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooFab = class MooFab {
    static containerless = true;
    icon;
    label;
    class;
    click;
    external;
    url;
    route;
    fabEl;
    attached() {
        new MDCRipple(this.fabEl);
    }
    handleClick() {
        if (this.click) {
            this.click();
        }
    }
    get extendedClass() {
        if (this.label) {
            return 'mdc-fab--extended';
        }
        return 'mdc-fab--mini';
    }
};
MooFab = _ts_decorate$e([
    customElement(__au2ViewDef$e)
], MooFab);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooFab.prototype, "icon", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooFab.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooFab.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooFab.prototype, "click", void 0);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooFab.prototype, "external", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooFab.prototype, "url", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooFab.prototype, "route", void 0);

const name$d = "moo-switch";
const template$d = "<label class=\"pt-1 pe-1\" for=\"switch\">${label}</label>\n<md-switch ref=\"switch\" selected.bind=\"value\" id=\"switch\"></md-switch>\n";
const dependencies$d = [];
let _e$d;
function register$d(container) {
    if (!_e$d) {
        _e$d = CustomElement.define({
            name: name$d,
            template: template$d,
            dependencies: dependencies$d
        });
    }
    container.register(_e$d);
}

const __au2ViewDef$d = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$d,
    dependencies: dependencies$d,
    name: name$d,
    register: register$d,
    template: template$d
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$d(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooSwitch = class MooSwitch {
    static containerless = true;
    value;
    class;
    change;
    label;
    switch;
    attached() {
        this.switch.selected = this.value;
        this.switch.addEventListener('change', ()=>this.handleChange());
    }
    handleChange() {
        this.value = !this.value;
        this.change();
    }
};
MooSwitch = _ts_decorate$d([
    customElement(__au2ViewDef$d)
], MooSwitch);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Boolean)
], MooSwitch.prototype, "value", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooSwitch.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Function)
], MooSwitch.prototype, "change", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooSwitch.prototype, "label", void 0);

const name$c = "moo-data-grid";
const template$c = "<div id=\"grid-control\" ref=\"control\" class=\"w-100\"></div>\n";
const dependencies$c = [];
let _e$c;
function register$c(container) {
    if (!_e$c) {
        _e$c = CustomElement.define({
            name: name$c,
            template: template$c,
            dependencies: dependencies$c
        });
    }
    container.register(_e$c);
}

const __au2ViewDef$c = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$c,
    dependencies: dependencies$c,
    name: name$c,
    register: register$c,
    template: template$c
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$c(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooDataGrid = class MooDataGrid {
    static containerless = true;
    items = null;
    columns;
    load;
    filterVisible = true;
    headerFilterVisible = false;
    onExportToExcel = false;
    pendingOnly;
    hiddenFilter;
    searchPanelVisible = true;
    onRowUpdating;
    onRowPrepared;
    allowAdding = false;
    allowEditing = false;
    allowDeleting = false;
    allowChoosing = false;
    masterDetail = {};
    extraParams = {};
    searchPanelText;
    storageKey;
    allowColumnResizing;
    allowColumnReordering;
    columnResizingMode;
    confirmDeleteMessage;
    editingMode = 'batch';
    allowedPageSizes = [
        1,
        10,
        25,
        50,
        100
    ];
    popupTitle;
    formItemOptions;
    onOptionChangedFunction;
    onInitNewRowFunction;
    onRowInsertedFunction;
    onRowUpdatedFunction;
    onRowValidating;
    onToolbarPreparing;
    onExporting;
    onCellPrepared;
    dataSource;
    onContentReady;
    //Value for storing filters on new accounts/currency/items filters
    auxFiltersForNewProduct;
    //Values for start and ending dates on toolbars for report.
    startDateForToolbar;
    endDateForToolbar;
    customizeColumns;
    onEditingStart;
    onEditorPreparing;
    closeOnOutsideClick;
    summary;
    control;
    //Array of editable datetime type fields.
    valuesDateTime = [
        'validThrough'
    ];
    dataGrid;
    dataGridControl;
    attached() {
        this.dataGrid = new DataGrid(this.control, {
            allowColumnReordering: this.allowColumnReordering || true,
            filterRow: {
                visible: this.filterVisible,
                applyFilter: 'auto'
            },
            headerFilter: {
                visible: this.headerFilterVisible
            },
            searchPanel: {
                visible: this.searchPanelVisible,
                width: 300,
                text: this.searchPanelText,
                searchVisibleColumnsOnly: true
            },
            loadPanel: {
                width: 100
            },
            dataSource: this.items || this.dataSource,
            export: {
                enabled: true
            },
            columnAutoWidth: true,
            rowAlternationEnabled: true,
            remoteOperations: this.items ? false : {
                filtering: true,
                sorting: true,
                paging: true,
                grouping: false,
                summary: false
            },
            scrolling: {
                mode: 'standard',
                showScrollbar: 'always'
            },
            summary: this.summary ?? {},
            paging: {
                enabled: true,
                pageSize: 25
            },
            stateStoring: {
                enabled: !this.searchPanelText,
                type: 'sessionStorage',
                storageKey: this.storageKey || 'defaultStorageKey'
            },
            pager: {
                showPageSizeSelector: true,
                allowedPageSizes: this.allowedPageSizes
            },
            allowColumnResizing: this.allowColumnResizing || true,
            columnResizingMode: this.columnResizingMode || true,
            cellHintEnabled: true,
            showBorders: true,
            showRowLines: false,
            showColumnLines: true,
            columns: this.columns,
            onRowUpdating: this.onRowUpdating,
            onRowPrepared: this.onRowPrepared,
            onRowExpanding: this.onRowExpanding,
            onRowValidating: this.onRowValidating ? (e)=>this.onRowValidating(e) : undefined,
            onContentReady: this.onContentReady ? this.onContentReady : (e)=>{
                // @ts-ignore
                e.element.querySelector('.dx-datagrid-text-content').classList.remove('dx-text-content-alignment-left');
                const countEl = document.getElementById('grid-control-data-count');
                if (this.items && countEl) {
                    // @ts-ignore
                    countEl.innerText = 'Total Records: ' + this.items.length;
                } else if (this.dataSource && countEl) {
                    countEl.innerText = 'Total Records: ' + this.dataSource.totalCount();
                }
            },
            onOptionChanged: this.onOptionChangedFunction ? (e)=>this.onOptionChangedFunction(e, this.auxFiltersForNewProduct) : undefined,
            onInitNewRow: this.onInitNewRowFunction ? (e)=>this.onInitNewRowFunction(e) : undefined,
            onRowInserted: this.onRowInsertedFunction ? (e)=>this.onRowInsertedFunction(e, this.auxFiltersForNewProduct) : undefined,
            onRowUpdated: this.onRowUpdatedFunction ? (e)=>this.onRowUpdatedFunction(e) : undefined,
            onCellPrepared: this.onCellPrepared ? (e)=>this.onCellPrepared(e) : undefined,
            onEditingStart: this.onEditingStart ? (e)=>this.onEditingStart(e) : undefined,
            columnChooser: {
                enabled: this.allowChoosing,
                mode: 'select'
            },
            ...this.prepareEditingOptions(),
            masterDetail: {
                enabled: typeof this.masterDetail === 'object' ? false : this.masterDetail,
                template: this.masterDetail
            }
        });
    }
    /**
     * Prepares the editing options of the Grid based of the binded elements.
     * @returns the editing object for the Grid.
     */ prepareEditingOptions() {
        return {
            allowUpdating: this.allowEditing,
            allowAdding: this.allowAdding,
            allowDeleting: this.allowDeleting,
            selectTextOnEditStart: true,
            startEditAction: 'click',
            mode: this.editingMode,
            useIcons: true,
            form: {
                colCountByScreen: {
                    xs: 2,
                    sm: 2,
                    md: 3,
                    lg: 4
                },
                items: this.formItemOptions ? [
                    ...this.formItemOptions
                ] : undefined
            },
            popup: {
                title: this.popupTitle ? this.popupTitle : 'Edit',
                closeOnOutsideClick: !this.closeOnOutsideClick,
                showTitle: true
            },
            texts: {
                confirmDeleteMessage: this.confirmDeleteMessage || 'Are you sure you want to delete this record? WARNING: This immediately deletes this record.'
            }
        };
    }
    /**
     * Activates a loader and hides the component that trigers
     * @param {Component to hide} data
     * @param {Loader to activate} loaderElement
     */ startLoader(data, loaderElement) {
        data.component.option('visible', false);
        loaderElement.classList.remove('d-none');
        loaderElement.classList.add('d-block');
    }
    /**
     * deactivates a loader and shows the component that trigers
     * @param {Component to hide} data
     * @param {Loader to activate} loaderElement
     */ endLoader(data, loaderElement) {
        loaderElement.classList.remove('d-block');
        loaderElement.classList.add('d-none');
        data.component.option('visible', true);
    }
    onRowExpanding = (e)=>{
        e.component.collapseAll(-1);
    };
};
MooDataGrid = _ts_decorate$c([
    customElement(__au2ViewDef$c)
], MooDataGrid);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "items", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "columns", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "load", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "filterVisible", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "headerFilterVisible", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onExportToExcel", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "pendingOnly", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "hiddenFilter", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "searchPanelVisible", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowUpdating", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowPrepared", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowAdding", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowEditing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowDeleting", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowChoosing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "masterDetail", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "extraParams", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "searchPanelText", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "storageKey", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowColumnResizing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowColumnReordering", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "columnResizingMode", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "confirmDeleteMessage", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "editingMode", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "allowedPageSizes", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "popupTitle", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "formItemOptions", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onOptionChangedFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onInitNewRowFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowInsertedFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowUpdatedFunction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onRowValidating", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onToolbarPreparing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onExporting", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onCellPrepared", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "dataSource", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onContentReady", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "auxFiltersForNewProduct", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "startDateForToolbar", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "endDateForToolbar", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "customizeColumns", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onEditingStart", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "onEditorPreparing", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "closeOnOutsideClick", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooDataGrid.prototype, "summary", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooDataGrid.prototype, "control", void 0);

const mooTabBar = '';

const name$b = "moo-tab-bar";
const template$b = "<div class=\"mdc-tab-bar ${class}\" role=\"tablist\" ref=\"tabBarEl\">\n    <div class=\"mdc-tab-scroller\">\n        <div class=\"mdc-tab-scroller__scroll-area\">\n            <div class=\"mdc-tab-scroller__scroll-content\">\n                <au-slot></au-slot>\n            </div>\n        </div>\n    </div>\n</div>\n";
const dependencies$b = [];
let _e$b;
function register$b(container) {
    if (!_e$b) {
        _e$b = CustomElement.define({
            name: name$b,
            template: template$b,
            dependencies: dependencies$b
        });
    }
    container.register(_e$b);
}

const __au2ViewDef$b = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$b,
    dependencies: dependencies$b,
    name: name$b,
    register: register$b,
    template: template$b
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$b(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooTabBar = class MooTabBar {
    static containerless = true;
    static capture = true;
    id;
    class;
    tabBarEl;
    attached() {
        new MDCTabBar(this.tabBarEl);
    }
};
MooTabBar = _ts_decorate$b([
    customElement(__au2ViewDef$b)
], MooTabBar);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooTabBar.prototype, "id", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooTabBar.prototype, "class", void 0);

const name$a = "moo-tab";
const template$a = "<button class=\"mdc-tab ${tabClass}\" role=\"tab\" aria-selected=\"true\" tabindex=\"0\" click.trigger=\"setTab()\" type=\"button\">\n          <span class=\"mdc-tab__content\">\n            <span class=\"mdc-tab__icon material-icons\" aria-hidden=\"true\" if.bind=\"icon\">${icon}</span>\n            <span class=\"mdc-tab__text-label\">${label}</span>\n          </span>\n    <span class=\"mdc-tab-indicator ${indicatorClass}\">\n            <span class=\"mdc-tab-indicator__content mdc-tab-indicator__content--underline\"></span>\n          </span>\n    <span class=\"mdc-tab__ripple\"></span>\n    <div class=\"mdc-tab__focus-ring\"></div>\n</button>\n";
const dependencies$a = [];
let _e$a;
function register$a(container) {
    if (!_e$a) {
        _e$a = CustomElement.define({
            name: name$a,
            template: template$a,
            dependencies: dependencies$a
        });
    }
    container.register(_e$a);
}

const __au2ViewDef$a = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$a,
    dependencies: dependencies$a,
    name: name$a,
    register: register$a,
    template: template$a
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$a(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooTab = class MooTab {
    static containerless = true;
    active;
    id;
    class;
    label;
    icon;
    tab;
    value;
    get tabClass() {
        if (this.active) {
            return 'mdc-tab--active';
        }
        return '';
    }
    get indicatorClass() {
        if (this.active) {
            return 'mdc-tab-indicator--active';
        }
        return '';
    }
    setTab() {
        this.tab = this.value;
    }
};
MooTab = _ts_decorate$a([
    customElement(__au2ViewDef$a)
], MooTab);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Boolean)
], MooTab.prototype, "active", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTab.prototype, "id", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTab.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTab.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTab.prototype, "icon", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooTab.prototype, "tab", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooTab.prototype, "value", void 0);

const mooSelect = '';

const name$9 = "moo-select";
const template$9 = "<div class=\"mdc-select mdc-select--filled ${class} ${requiredClass}\" ref=\"selectEl\">\n    <div class=\"mdc-select__anchor\"\n         role=\"button\"\n         aria-haspopup=\"listbox\"\n         aria-expanded=\"false\"\n         aria-required.bind=\"required\">\n        <span class=\"mdc-select__ripple\"></span>\n        <span id=\"demo-label\" class=\"mdc-floating-label\">${label}</span>\n        <span class=\"mdc-select__selected-text-container\">\n      <span id=\"demo-selected-text\" class=\"mdc-select__selected-text\"></span>\n    </span>\n        <span class=\"mdc-select__dropdown-icon\">\n      <svg\n          class=\"mdc-select__dropdown-icon-graphic\"\n          viewBox=\"7 10 10 5\" focusable=\"false\">\n        <polygon\n            class=\"mdc-select__dropdown-icon-inactive\"\n            stroke=\"none\"\n            fill-rule=\"evenodd\"\n            points=\"7 10 12 15 17 10\">\n        </polygon>\n        <polygon\n            class=\"mdc-select__dropdown-icon-active\"\n            stroke=\"none\"\n            fill-rule=\"evenodd\"\n            points=\"7 15 12 10 17 15\">\n        </polygon>\n      </svg>\n    </span>\n        <span class=\"mdc-line-ripple\"></span>\n    </div>\n\n    <div class=\"mdc-select__menu mdc-menu mdc-menu-surface mdc-menu-surface--fullwidth\">\n        <au-slot></au-slot>\n    </div>\n</div>\n";
const dependencies$9 = [];
let _e$9;
function register$9(container) {
    if (!_e$9) {
        _e$9 = CustomElement.define({
            name: name$9,
            template: template$9,
            dependencies: dependencies$9
        });
    }
    container.register(_e$9);
}

const __au2ViewDef$9 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$9,
    dependencies: dependencies$9,
    name: name$9,
    register: register$9,
    template: template$9
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$9(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooSelect = class MooSelect {
    static containerless = true;
    label;
    options;
    value;
    class;
    required;
    readonly;
    selectEl;
    attached() {
        const select = new MDCSelect(this.selectEl);
        if (this.readonly) {
            select.disabled = true;
        }
        if (typeof this.value != 'undefined') {
            select.value = this.value?.toString();
        }
        select.listen('MDCSelect:change', ()=>{
            if (typeof this.value == 'number') {
                return this.value = parseInt(select.value);
            }
            this.value = select.value;
        });
    }
    get requiredClass() {
        if (this.required) {
            return 'mdc-select--required';
        }
    }
};
MooSelect = _ts_decorate$9([
    customElement(__au2ViewDef$9)
], MooSelect);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooSelect.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooSelect.prototype, "options", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooSelect.prototype, "value", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooSelect.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooSelect.prototype, "required", void 0);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooSelect.prototype, "readonly", void 0);

const mooList = '';

const name$8 = "moo-list";
const template$8 = "<ul class=\"mdc-deprecated-list\">\n    <au-slot></au-slot>\n</ul>\n";
const dependencies$8 = [];
let _e$8;
function register$8(container) {
    if (!_e$8) {
        _e$8 = CustomElement.define({
            name: name$8,
            template: template$8,
            dependencies: dependencies$8
        });
    }
    container.register(_e$8);
}

const __au2ViewDef$8 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$8,
    dependencies: dependencies$8,
    name: name$8,
    register: register$8,
    template: template$8
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$8(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooList = class MooList {
    static containerless = true;
} 
;
MooList = _ts_decorate$8([
    customElement(__au2ViewDef$8)
], MooList);

const mooBanner = '';

const name$7 = "moo-banner";
const template$7 = "<div class=\"mdc-banner\" role=\"banner\" ref=\"bannerEl\">\n    <div class=\"mdc-banner__content\"\n         role=\"alertdialog\"\n         aria-live=\"assertive\">\n        <div class=\"mdc-banner__graphic-text-wrapper\">\n            <div class=\"mdc-banner__text\">\n                <au-slot></au-slot>\n            </div>\n        </div>\n        <div class=\"mdc-banner__actions\">\n            <moo-button variant=\"secondary\" type=\"button\" class=\"mdc-banner__secondary-action\" if.bind=\"secondaryAction\">\n                <div class=\"mdc-button__ripple\"></div>\n                <div class=\"mdc-button__label\">\n                    ${secondaryAction}\n                </div>\n            </moo-button>\n            <moo-button variant=\"primary\" type=\"button\" class=\"mdc-banner__primary-action\" if.bind=\"primaryAction\">\n                <div class=\"mdc-button__ripple\"></div>\n                <div class=\"mdc-button__label\">\n                    ${primaryAction}\n                </div>\n            </moo-button>\n        </div>\n    </div>\n</div>\n";
const dependencies$7 = [];
let _e$7;
function register$7(container) {
    if (!_e$7) {
        _e$7 = CustomElement.define({
            name: name$7,
            template: template$7,
            dependencies: dependencies$7
        });
    }
    container.register(_e$7);
}

const __au2ViewDef$7 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$7,
    dependencies: dependencies$7,
    name: name$7,
    register: register$7,
    template: template$7
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$7(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooBanner = class MooBanner {
    static containerless = true;
    primaryAction;
    secondaryAction;
    open;
    bannerEl;
    banner;
    attached() {
        this.banner = new MDCBanner(this.bannerEl);
        if (this.open) {
            this.banner.open();
        }
    }
    openChanged() {
        if (this.open) {
            this.banner.open();
        } else {
            this.banner.close(CloseReason.PRIMARY);
        }
    }
};
MooBanner = _ts_decorate$7([
    customElement(__au2ViewDef$7)
], MooBanner);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooBanner.prototype, "primaryAction", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooBanner.prototype, "secondaryAction", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooBanner.prototype, "open", void 0);

const mooAccordion = '';

const name$6 = "moo-accordion";
const template$6 = "<div class=\"accordion-item ${extraAccordionClasses}\" ref=\"accordionItemEl\" ...$attrs>\n    <div class=\"accordion-header\" tabindex=\"0\" ref=\"accordionHeaderEl\">\n        <span>${header}</span>\n    </div>\n    <div class=\"accordion-content\">\n        <au-slot></au-slot>\n    </div>\n</div>\n";
const dependencies$6 = [];
let _e$6;
function register$6(container) {
    if (!_e$6) {
        _e$6 = CustomElement.define({
            name: name$6,
            template: template$6,
            dependencies: dependencies$6
        });
    }
    container.register(_e$6);
}

const __au2ViewDef$6 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$6,
    dependencies: dependencies$6,
    name: name$6,
    register: register$6,
    template: template$6
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$6(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooAccordion = class MooAccordion {
    static containerless = true;
    static capture = true;
    header;
    accordionItemEl;
    accordionHeaderEl;
    closeAllOtherAccordions(element) {
        const accordionHeaders = document.querySelectorAll('.accordion-header');
        accordionHeaders.forEach((header)=>{
            if (header !== element) {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                header.parentElement.classList.remove('accordion-expanded');
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-expect-error
                header.nextElementSibling.style.maxHeight = 0;
            }
        });
    }
    attached() {
        this.accordionHeaderEl.addEventListener('click', ()=>{
            const content = this.accordionHeaderEl.nextElementSibling;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            const isOpen = this.accordionHeaderEl.parentElement.classList.contains('accordion-expanded');
            this.closeAllOtherAccordions(this.accordionHeaderEl);
            if (isOpen) {
                content.style.maxHeight = '0';
            } else {
                content.style.maxHeight = content.scrollHeight + 50 + 'px';
            }
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            this.accordionHeaderEl.parentElement.classList.toggle('accordion-expanded');
        });
    }
};
MooAccordion = _ts_decorate$6([
    customElement(__au2ViewDef$6)
], MooAccordion);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooAccordion.prototype, "header", void 0);

const mooRadio = '';

const name$5 = "moo-radio";
const template$5 = "<div class=\"mdc-radio\" ref=\"radioEl\">\n    <input class=\"mdc-radio__native-control\" type=\"radio\" name=\"radios\" checked.bind=\"checked\" disabled.bind=\"disabled\">\n    <div class=\"mdc-radio__background\">\n        <div class=\"mdc-radio__outer-circle\"></div>\n        <div class=\"mdc-radio__inner-circle\"></div>\n    </div>\n    <div class=\"mdc-radio__ripple\"></div>\n    <div class=\"mdc-radio__focus-ring\"></div>\n</div>\n";
const dependencies$5 = [];
let _e$5;
function register$5(container) {
    if (!_e$5) {
        _e$5 = CustomElement.define({
            name: name$5,
            template: template$5,
            dependencies: dependencies$5
        });
    }
    container.register(_e$5);
}

const __au2ViewDef$5 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$5,
    dependencies: dependencies$5,
    name: name$5,
    register: register$5,
    template: template$5
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$5(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooRadio = class MooRadio {
    static containerless = true;
    label;
    options;
    model;
    value;
    class;
    disabled;
    checked = false;
    radioEl;
    radio;
    attached() {
        if (this.model == this.value) {
            this.checked = true;
        }
        console.log('this.model', this.model);
        console.log('this.value', this.value);
        this.radio = new MDCRadio(this.radioEl);
        console.log(this.checked);
    }
    clickHandler() {
        console.log('clicked', this.radio.value);
    }
    handleRadioChecked() {
        console.log('radio checked', this.radio.checked);
    }
    handleRadioValue() {
        console.log('radio value', this.radio.value);
    }
    handleCheckChanged() {
        console.log('this.checked', this.checked);
    }
};
MooRadio = _ts_decorate$5([
    customElement(__au2ViewDef$5)
], MooRadio);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooRadio.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooRadio.prototype, "options", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooRadio.prototype, "model", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Object)
], MooRadio.prototype, "value", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], MooRadio.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooRadio.prototype, "disabled", void 0);
__decorate([
    watch('radio.checked'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], MooRadio.prototype, "handleRadioChecked", null);
__decorate([
    watch('radio'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], MooRadio.prototype, "handleRadioValue", null);
__decorate([
    watch('checked'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], MooRadio.prototype, "handleCheckChanged", null);

const mooFormField = '';

const name$4 = "moo-form-field";
const template$4 = "<div class=\"mdc-form-field\" ref=\"formFieldEl\">\n    <au-slot></au-slot>\n    <label>${label}</label>\n</div>\n";
const dependencies$4 = [];
let _e$4;
function register$4(container) {
    if (!_e$4) {
        _e$4 = CustomElement.define({
            name: name$4,
            template: template$4,
            dependencies: dependencies$4
        });
    }
    container.register(_e$4);
}

const __au2ViewDef$4 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$4,
    dependencies: dependencies$4,
    name: name$4,
    register: register$4,
    template: template$4
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$4(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooFormField = class MooFormField {
    static containerless = true;
    label;
    options;
    class;
    disabled;
    formFieldEl;
    formField;
    attached() {
        this.formField = new MDCFormField(this.formFieldEl);
    }
};
MooFormField = _ts_decorate$4([
    customElement(__au2ViewDef$4)
], MooFormField);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooFormField.prototype, "label", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooFormField.prototype, "options", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooFormField.prototype, "class", void 0);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], MooFormField.prototype, "disabled", void 0);

const mooChipSet = '';

const name$3 = "moo-chip-set";
const template$3 = "<span class=\"mdc-evolution-chip-set\" role=\"grid\" ref=\"chipSetEl\">\n    <span class=\"mdc-evolution-chip-set__chips\" role=\"presentation\">\n        <au-slot></au-slot>\n    </span>\n</span>\n";
const dependencies$3 = [];
let _e$3;
function register$3(container) {
    if (!_e$3) {
        _e$3 = CustomElement.define({
            name: name$3,
            template: template$3,
            dependencies: dependencies$3
        });
    }
    container.register(_e$3);
}

const __au2ViewDef$3 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$3,
    dependencies: dependencies$3,
    name: name$3,
    register: register$3,
    template: template$3
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$3(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooChipSet = class MooChipSet {
    static containerless = true;
    chipSetEl;
    size;
    attached() {
        new MDCChipSet(this.chipSetEl);
    }
};
MooChipSet = _ts_decorate$3([
    customElement(__au2ViewDef$3)
], MooChipSet);
__decorate([
    bindable,
    __metadata("design:type", Number)
], MooChipSet.prototype, "size", void 0);

const mooChip = '';

const name$2 = "moo-chip";
const template$2 = "<span class=\"mdc-evolution-chip\" role=\"row\" id=\"c0\">\n      <span class=\"mdc-evolution-chip__cell mdc-evolution-chip__cell--primary\" role=\"gridcell\">\n        <button class=\"mdc-evolution-chip__action mdc-evolution-chip__action--primary\" type=\"button\" tabindex=\"0\">\n          <span class=\"mdc-evolution-chip__ripple mdc-evolution-chip__ripple--primary\"></span>\n          <span class=\"mdc-evolution-chip__text-label\">\n              <au-slot></au-slot>\n          </span>\n        </button>\n      </span>\n    </span>\n";
const dependencies$2 = [];
let _e$2;
function register$2(container) {
    if (!_e$2) {
        _e$2 = CustomElement.define({
            name: name$2,
            template: template$2,
            dependencies: dependencies$2
        });
    }
    container.register(_e$2);
}

const __au2ViewDef$2 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$2,
    dependencies: dependencies$2,
    name: name$2,
    register: register$2,
    template: template$2
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$2(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooChip = class MooChip {
    static containerless = true;
} 
;
MooChip = _ts_decorate$2([
    customElement(__au2ViewDef$2)
], MooChip);

const mooCheckbox = '';

const name$1 = "moo-checkbox";
const template$1 = "<div class=\"mdc-touch-target-wrapper\">\n    <div class=\"mdc-checkbox mdc-checkbox--touch\" ref=\"checkboxEl\">\n        <input type=\"checkbox\"\n               class=\"mdc-checkbox__native-control\"\n               checked.bind=\"checked\"/>\n        <div class=\"mdc-checkbox__background\">\n            <svg class=\"mdc-checkbox__checkmark\"\n                 viewBox=\"0 0 24 24\">\n                <path class=\"mdc-checkbox__checkmark-path\"\n                      fill=\"none\"\n                      d=\"M1.73,12.91 8.1,19.28 22.79,4.59\"/>\n            </svg>\n            <div class=\"mdc-checkbox__mixedmark\"></div>\n        </div>\n        <div class=\"mdc-checkbox__ripple\"></div>\n        <div class=\"mdc-checkbox__focus-ring\"></div>\n    </div>\n</div>\n";
const dependencies$1 = [];
let _e$1;
function register$1(container) {
    if (!_e$1) {
        _e$1 = CustomElement.define({
            name: name$1,
            template: template$1,
            dependencies: dependencies$1
        });
    }
    container.register(_e$1);
}

const __au2ViewDef$1 = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template$1,
    dependencies: dependencies$1,
    name: name$1,
    register: register$1,
    template: template$1
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate$1(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooCheckbox = class MooCheckbox {
    static containerless = true;
    checkboxEl;
    checked;
    changed;
    value;
    attached() {
        new MDCCheckbox(this.checkboxEl);
    }
    checkedChanged() {
        if (this.changed) {
            this.changed(this.value, this.checked);
        }
    }
};
MooCheckbox = _ts_decorate$1([
    customElement(__au2ViewDef$1)
], MooCheckbox);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", Boolean)
], MooCheckbox.prototype, "checked", void 0);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooCheckbox.prototype, "changed", void 0);
__decorate([
    bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    __metadata("design:type", String)
], MooCheckbox.prototype, "value", void 0);

const mooMenu = '';

const name = "moo-menu";
const template = "<div class=\"mdc-menu mdc-menu-surface\" ref=\"menuEl\">\n    <au-slot></au-slot>\n</div>\n";
const dependencies = [];
let _e;
function register(container) {
    if (!_e) {
        _e = CustomElement.define({
            name,
            template,
            dependencies
        });
    }
    container.register(_e);
}

const __au2ViewDef = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    default: template,
    dependencies,
    name,
    register,
    template
}, Symbol.toStringTag, { value: 'Module' }));

function _ts_decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for(var i = decorators.length - 1; i >= 0; i--)if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}
let MooMenu = class MooMenu {
    static containerless = true;
    open = false;
    menuEl;
    menu;
    attached() {
        this.menu = new MDCMenu(this.menuEl);
        this.menu.open = this.open;
    }
    openChanged() {
        if (this.menu) {
            this.menu.open = this.open;
        }
    }
};
MooMenu = _ts_decorate([
    customElement(__au2ViewDef)
], MooMenu);
__decorate([
    bindable,
    __metadata("design:type", Object)
], MooMenu.prototype, "open", void 0);

const elements = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get MooAccordion () { return MooAccordion; },
    get MooBanner () { return MooBanner; },
    get MooButton () { return MooButton; },
    get MooCard () { return MooCard; },
    get MooCardContent () { return MooCardContent; },
    get MooCardFooter () { return MooCardFooter; },
    get MooCardHeader () { return MooCardHeader; },
    get MooCheckbox () { return MooCheckbox; },
    get MooChip () { return MooChip; },
    get MooChipSet () { return MooChipSet; },
    get MooCircularProgress () { return MooCircularProgress; },
    get MooDataGrid () { return MooDataGrid; },
    get MooDialog () { return MooDialog; },
    get MooDrawer () { return MooDrawer; },
    get MooFab () { return MooFab; },
    get MooFormField () { return MooFormField; },
    get MooList () { return MooList; },
    get MooListItem () { return MooListItem; },
    get MooMenu () { return MooMenu; },
    get MooRadio () { return MooRadio; },
    get MooSelect () { return MooSelect; },
    get MooSwitch () { return MooSwitch; },
    get MooTab () { return MooTab; },
    get MooTabBar () { return MooTabBar; },
    get MooTextField () { return MooTextField; },
    get MooTopbar () { return MooTopbar; }
}, Symbol.toStringTag, { value: 'Module' }));

let TakeValueConverter = class TakeValueConverter {
    toView(value, amount) {
        return value.slice(0, amount);
    }
};
TakeValueConverter = __decorate([
    valueConverter('take')
], TakeValueConverter);

let SkipValueConverter = class SkipValueConverter {
    toView(value, amount) {
        return value.slice(amount);
    }
};
SkipValueConverter = __decorate([
    valueConverter('skip')
], SkipValueConverter);

const valueConverters = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get SkipValueConverter () { return SkipValueConverter; },
    get TakeValueConverter () { return TakeValueConverter; }
}, Symbol.toStringTag, { value: 'Module' }));

const main = '';

class BetsyWebComponentsPlugin {
    #configuration;
    static configure(...args) {
        const instance = new BetsyWebComponentsPlugin();
        if (typeof args[0] === 'function') {
            instance.#configuration = {
                iconMap: new Map()
            };
            args[0](instance.#configuration);
        } else {
            instance.#configuration = args[0];
        }
        if (!instance.#configuration.formatDateTime) {
            instance.#configuration.formatDateTime = (date)=>new Intl.DateTimeFormat('default', {
                    dateStyle: 'full'
                }).format(typeof date === 'string' ? new Date(date) : date);
        }
        if (!instance.#configuration.formatDate) {
            instance.#configuration.formatDate = (date)=>new Intl.DateTimeFormat('default', {
                    month: '2-digit',
                    day: '2-digit',
                    year: 'numeric'
                }).format(typeof date === 'string' ? new Date(date) : date);
        }
        if (!instance.#configuration.formatNumber) {
            instance.#configuration.formatNumber = (number)=>new Intl.NumberFormat('default', {
                    maximumFractionDigits: 2
                }).format(number == null ? 0 : Number(number));
        }
        if (!instance.#configuration.formatCurrency) {
            instance.#configuration.formatCurrency = (number)=>new Intl.NumberFormat('default', {
                    style: 'currency',
                    currency: 'usd'
                }).format(number == null ? 0 : Number(number));
        }
        if (!instance.#configuration.formatPercent) {
            instance.#configuration.formatPercent = (number)=>new Intl.NumberFormat('default', {
                    style: 'percent'
                }).format(number == null ? 0 : Number(number));
        }
        return instance;
    }
    register(container) {
        container.register(attributes);
        container.register(elements);
        container.register(valueConverters);
        container.register(Registration.instance(IBetsyWebComponentsConfiguration, this.#configuration));
        container.register(ValidationHtmlConfiguration.customize((options)=>{
            options.DefaultTrigger = ValidationTrigger.changeOrFocusout;
        }));
        // container = container.register(AppTask.beforeCreate(IContainer, async c => {
        //     // console
        //     console.log(this.#configuration)
        //     c.register(elements);
        //     c.register(attributes);
        // }));
        return container;
    }
}

export { BetsyWebComponentsPlugin, IBetsyWebComponentsConfiguration, attributes, elements, valueConverters };
//# sourceMappingURL=index.mjs.map
